package
Version:
v1.2.0
Opens a new window with list of versions in this module.
Published: Mar 25, 2026
License: MIT
Opens a new window with license information.
Imports: 14
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Execute runs the root command.
func SetVersionInfo(version, commit string)
SetVersionInfo sets version and commit info from build ldflags.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.